@@ -17,8 +17,6 @@ egg_recent_model_sort_get_type (void)
     static const GEnumValue values[] = {
       { EGG_RECENT_MODEL_SORT_MRU, "EGG_RECENT_MODEL_SORT_MRU", "mru" },
       { EGG_RECENT_MODEL_SORT_LRU, "EGG_RECENT_MODEL_SORT_LRU", "lru" },
-      { EGG_RECENT_MODEL_SORT_MFU, "EGG_RECENT_MODEL_SORT_MFU", "mfu" },
-      { EGG_RECENT_MODEL_SORT_LFU, "EGG_RECENT_MODEL_SORT_LFU", "lfu" },
       { EGG_RECENT_MODEL_SORT_NONE, "EGG_RECENT_MODEL_SORT_NONE", "none" },
       { 0, NULL, NULL }
     };
@@ -27,6 +25,5 @@ egg_recent_model_sort_get_type (void)
   return etype;
 }
 
-
 /* Generated data ends here */
 
